"""
:sub_package: wizzi_utils.socket
:sub_package: wizzi_utils.open_cv
"""
try:
    from wizzi_utils.open_cv.test.test_open_cv_tools import *
except ModuleNotFoundError as e:
    pass
